#!/usr/env/bin python
"""
CMSMonitoring: set of utils for CMS monitoring
"""
# Check GH actions
__version__ = "0.6.2"
__all__ = [__version__]
